@@ -1,5 +1,3 @@
-from ast import Sub
-
 from riot import Venv
 from riot import latest
 
@@ -12,7 +10,10 @@ venv = Venv(
             name="tests",
             venvs=[
                 Venv(
-                    pkgs={"mypy": latest},
+                    pkgs={
+                        "mypy": latest,
+                        "sphinx": latest,
+                    },
                     pys=SUPPORTED_PYTHON_VERSIONS[2:],
                 ),
                 Venv(pys=SUPPORTED_PYTHON_VERSIONS[:2]),
@@ -34,13 +35,13 @@ venv = Venv(
         Venv(
             name="mypy",
             pkgs={"mypy": latest},
-            command="mypy {cmdargs}",
+            command="mypy --install-types --non-interactive {cmdargs}",
             pys=["3"],
         ),
         Venv(
             name="flake8",
             pkgs={
-                "flake8": latest,
+                "flake8": "<5",
                 "flake8-isort": latest,
             },
             command="flake8 {cmdargs}",
